import { Command, Flags } from '@oclif/core';
import { createContext, getDefaultConfigPath } from './lib/Context.js';
import { StandardColors } from './lib/StandardColors.js';
/*

  TODO - Move transactional flags and examples to another command class extension to
  allow base command to be used for non-transactional commands.


*/
export class TransactionCommand extends Command {
    static baseExamples = [
        '<%= config.bin %> <%= command.id %> --json',
        '<%= config.bin %> <%= command.id %> --log-level debug',
        '<%= config.bin %> <%= command.id %> --keypair /path/to/keypair.json',
        '<%= config.bin %> <%= command.id %> --keypair usb://ledger?key=0',
        '<%= config.bin %> <%= command.id %> --rpc http://localhost:8899',
        '<%= config.bin %> <%= command.id %> --commitment finalized',
    ];
    // define flags that can be inherited by any command that extends BaseCommand
    static baseFlags = {
        commitment: Flags.string({
            options: ['processed', 'confirmed', 'finalized'],
            summary: 'Commitment level',
            helpGroup: 'GLOBAL',
        }),
        config: Flags.file({
            char: 'c',
            description: 'Path to config file. Default is ~/.config/mplx/config.json',
            helpGroup: 'GLOBAL',
        }),
        keypair: Flags.string({
            char: 'k',
            summary: 'Path to keypair file (/path/keypair.json) or ledger (e.g. usb://ledger?key=0)',
            helpGroup: 'GLOBAL',
        }),
        'log-level': Flags.option({
            default: 'info',
            helpGroup: 'GLOBAL',
            options: ['debug', 'warn', 'error', 'info', 'trace'],
            summary: 'Specify level for logging.',
        })(),
        payer: Flags.string({
            char: 'p',
            summary: 'Path to keypair file (/path/keypair.json) or ledger (e.g. usb://ledger?key=0)',
            helpGroup: 'GLOBAL',
        }),
        rpc: Flags.string({
            char: 'r',
            name: 'rpc',
            summary: 'RPC URL for the cluster',
            helpGroup: 'GLOBAL',
        }),
    };
    // add the --json flag
    static enableJsonFlag = true;
    args;
    context;
    flags;
    async catch(err) {
        // add any custom logic to handle errors from the command
        // or simply return the parent class error handling
        return super.catch(err);
    }
    async finally(_) {
        // called after run and catch regardless of whether or not the command errored
        return super.finally(_);
    }
    async init() {
        await super.init();
        const { args, flags } = await this.parse({
            args: this.ctor.args,
            baseFlags: super.ctor.baseFlags,
            enableJsonFlag: this.ctor.enableJsonFlag,
            flags: this.ctor.flags,
            strict: this.ctor.strict,
        });
        this.flags = flags;
        this.args = args;
        const configPath = this.flags.config ?? getDefaultConfigPath(this.config.configDir);
        this.context = await createContext(configPath, {
            commitment: this.flags.commitment,
            keypair: this.flags.keypair,
            payer: this.flags.payer,
            rpcUrl: this.flags.rpc,
            explorer: this.flags.explorer,
        });
    }
    logSuccess(message) {
        this.log(StandardColors.success(message));
    }
}
