import { Args, Command, Flags } from '@oclif/core';
import { getDefaultConfigPath, readConfig } from '../../lib/Context.js';
import { ensureDirectoryExists, writeJsonSync } from '../../lib/file.js';
import { dirname } from 'path';
export default class ConfigSetCommand extends Command {
    static description = 'Set a config value from a key';
    static args = {
        key: Args.string({
            description: 'The key to set',
            required: true,
            options: ['rpcUrl', 'commitment', 'payer', 'keypair'],
        }),
        value: Args.string({ description: 'The value to set', required: true }),
    };
    static examples = [
        '<%= config.bin %> <%= command.id %> keypair /path/to/keypair.json',
        '<%= config.bin %> <%= command.id %> payer /path/to/keypair.json',
        '<%= config.bin %> <%= command.id %> rpcUrl http://localhost:8899',
        '<%= config.bin %> <%= command.id %> commitment confirmed',
    ];
    static flags = {
        config: Flags.file({ char: 'c', description: 'path to config file. Default is ~/.config/mplx/config.json' }),
    };
    async run() {
        const { flags, args } = await this.parse(ConfigSetCommand);
        const { key, value } = args;
        const path = flags.config ?? getDefaultConfigPath(this.config.configDir);
        const config = readConfig(path);
        config[key] = value;
        const dir = dirname(path);
        ensureDirectoryExists(dir);
        writeJsonSync(path, config);
        this.log(`Configuration updated: ${path}`);
    }
}
