import { Args, Command } from '@oclif/core';
import { dirname } from 'path';
import { getDefaultConfigPath, readConfig } from '../../../lib/Context.js';
import { ensureDirectoryExists, writeJsonSync } from '../../../lib/file.js';
export default class ConfigWalletRemoveCommand extends Command {
    static description = 'Remove a wallet from the config';
    static args = {
        name: Args.string({
            description: 'Name of wallet to remove from config',
            required: true,
        }),
    };
    static examples = [
        '<%= config.bin %> <%= command.id %> remove dev1',
    ];
    async run() {
        const { flags, args } = await this.parse(ConfigWalletRemoveCommand);
        const path = flags.config ?? getDefaultConfigPath(this.config.configDir);
        const config = readConfig(path);
        // find and remove wallet by name
        if (!config.wallets) {
            this.log('No wallets found');
        }
        else {
            const existingName = config.wallets.find((wallet) => wallet.name === args.name);
            if (!existingName) {
                this.error(`Wallet with name ${args.name} does not exist`);
            }
            config.wallets = config.wallets.filter((wallet) => wallet.name !== args.name);
            this.log(`Wallet ${args.name} removed from config.`);
            const dir = dirname(path);
            ensureDirectoryExists(dir);
            writeJsonSync(path, config);
        }
    }
}
