import umiSendTransaction from './sendTransaction.js';
const delay = (ms) => new Promise((resolve) => setTimeout(resolve, ms));
const umiSendAllTransactions = async (umi, transactions, options, onProgress) => {
    const transactionsPerSecond = 3; // Set default to 1 TPS
    const txInterval = 1000 / transactionsPerSecond; // Time between sending transactions (in ms)
    let results = [];
    // Process transactions sequentially
    let index = 0;
    for (const tx of transactions) {
        if (!tx) {
            console.log(`Transaction ${index} is null`);
            onProgress && onProgress(index, {
                signature: null,
                blockhash: null,
                err: 'Error Building Transaction',
            });
            index++;
            results.push({
                signature: null,
                blockhash: null,
                err: 'Error Building Transaction',
            });
            continue;
        }
        try {
            console.log(`Sending Transaction ${index} from umiSendAllTransactions`);
            const response = await umiSendTransaction(umi, tx, options);
            onProgress && onProgress(index, response);
            results.push(response);
        }
        catch (error) {
            // console.log(`Error sending Transaction ${index} from umiSendAllTransactions:`, error)
            const errorResponse = {
                signature: null,
                blockhash: null,
                err: error instanceof Error ? error.message : String(error),
            };
            onProgress && onProgress(index, errorResponse);
            results.push(errorResponse);
        }
        index++;
        // Wait for the interval before processing the next transaction
        await delay(txInterval);
    }
    return results;
};
export default umiSendAllTransactions;
