import fs from 'node:fs';
import mime from 'mime';
import { createGenericFile } from '@metaplex-foundation/umi';
const uploadFile = async (umi, filePath) => {
    try {
        const file = fs.readFileSync(filePath);
        const mimeType = mime.getType(filePath);
        const genericFile = createGenericFile(file, 'file', {
            tags: mimeType ? [{ name: 'mimeType', value: mimeType }] : [],
        });
        const [uploadResult] = await umi.uploader.upload([genericFile]);
        if (!uploadResult) {
            throw new Error('File upload failed');
        }
        return {
            uri: uploadResult,
            mimeType: mimeType || '',
        };
    }
    catch (error) {
        throw new Error(`File upload failed: ${error instanceof Error ? error.message : String(error)}`);
    }
};
export default uploadFile;
